==> attal_0.8.orig.tar.gz: attal-0.8/scenarioEditor/scenarioEditor.cpp <==
/****************************************************************
**
** Attal : Lords of Doom
**
** scenarioEditor.cpp
** main file for the scenario editor
**
** Version : $Id: scenarioEditor.cpp,v 1.3 2004/04/04 17:14:26 audoux Exp $
**
** Author(s) : Pascal Audoux
**
** Date : 27/08/2000
**
** Licence :    
**	This program is free software; you can redistribute it and/or modify
**   	it under the terms of the GNU General Public License as published by
**     	the Free Software Foundation; either version 2, or (at your option)
**      any later version.
**
**	This program is distributed in the hope that it will be useful,
** 	but WITHOUT ANY WARRANTY; without even the implied warranty of
**	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**	GNU General Public License for more details.
**
****************************************************************/



// include files for QT
#include <qapplication.h>
#include <qstring.h>
#include <qtextcodec.h>
#include <qtranslator.h>

// application specific includes
#include "scenarioEditor/scenarioInterface.h"
#include "libCommon/log.h"
#include "libClient/map.h"
#include "libClient/gui.h"
#include "conf.h"

Map * theMap;

QString IMAGE_PATH( IMAGE_DEFAULT_PATH );

QString SOUND_PATH( SOUND_DEFAULT_PATH );

QString DATA_PATH( DATA_DEFAULT_PATH );

QString THEME( THEME_DEFAULT );

int main( int argc, char **argv )
{
	QApplication app( argc, argv );
	QTranslator translator( 0 );
	translator.load( QString("scenario_editor_") + QTextCodec::locale(), "." );

	app.installTranslator( &translator );

	for( int i = 1; i < argc; i++ ) {
		if ( strcmp( argv[i], "-theme" ) == 0 ) {
			i++;
			if( i < argc ) {
				THEME = QString( argv[i] );
			}
		}	
	}
	useTheme();
	theMap = 0;
	
	ScenarioInterface edit;
	app.setMainWidget( &edit );
        edit.show();

	return app.exec();	
}

==> attal_0.9.2.orig.tar.gz: attal-0.9.2/scenarioEditor/scenarioEditor.cpp <==
/****************************************************************
**
** Attal : Lords of Doom
**
** scenarioEditor.cpp
** main file for the scenario editor
**
** Version : $Id: scenarioEditor.cpp,v 1.5 2004/08/22 14:23:32 audoux Exp $
**
** Author(s) : Pascal Audoux
**
** Date : 27/08/2000
**
** Licence :    
**	This program is free software; you can redistribute it and/or modify
**   	it under the terms of the GNU General Public License as published by
**     	the Free Software Foundation; either version 2, or (at your option)
**      any later version.
**
**	This program is distributed in the hope that it will be useful,
** 	but WITHOUT ANY WARRANTY; without even the implied warranty of
**	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**	GNU General Public License for more details.
**
****************************************************************/



// include files for QT
#include <qapplication.h>
#include <qstring.h>
#include <qtextcodec.h>
#include <qtranslator.h>

// application specific includes
#include "scenarioEditor/scenarioInterface.h"
#include "libCommon/log.h"
#include "libClient/map.h"
#include "libClient/gui.h"
#include "conf.h"

Map * theMap;

QString IMAGE_PATH( IMAGE_DEFAULT_PATH );

QString MUSIC_PATH( MUSIC_DEFAULT_PATH );

QString SOUND_PATH( SOUND_DEFAULT_PATH );

QString DATA_PATH( DATA_DEFAULT_PATH );

QString CAMPAIGN_PATH( CAMPAIGN_DEFAULT_PATH );

QString SCENARIO_PATH( SCENARIO_DEFAULT_PATH );

QString THEME( THEME_DEFAULT );

int main( int argc, char **argv )
{
	QApplication app( argc, argv );
	QTranslator translator( 0 );
	translator.load( QString("scenario_editor_") + QTextCodec::locale(), "." );

	app.installTranslator( &translator );

	for( int i = 1; i < argc; i++ ) {
		if ( strcmp( argv[i], "-theme" ) == 0 ) {
			i++;
			if( i < argc ) {
				THEME = QString( argv[i] );
			}
		}	
	}
	useTheme();
	theMap = 0;
	
	ScenarioInterface edit;
	app.setMainWidget( &edit );
        edit.show();

	return app.exec();	
}
